@@ -2,8 +2,8 @@ from typing import List, Union, Optional, Tuple
 
 from bs4 import BeautifulSoup
 from feeluown.library import SongModel, BriefArtistModel, PlaylistModel, BriefPlaylistModel, BriefUserModel, \
-    BriefSongModel, ArtistModel, CommentModel, VideoModel, BriefVideoModel, BriefAlbumModel, AlbumModel
-from feeluown.models import SearchModel, ModelExistence
+    BriefSongModel, ArtistModel, CommentModel, VideoModel, BriefVideoModel, BriefAlbumModel, AlbumModel, \
+    SimpleSearchResult
 
 from fuo_bilibili import __identifier__
 from fuo_bilibili.api import SearchType
@@ -48,6 +48,7 @@ class BSongModel(SongModel):
             )],
             duration=au.duration.total_seconds() * 1000,
             lyric=au.lyric,
+            pic_url=au.cover,
         )
 
     @classmethod
@@ -79,6 +80,7 @@ class BSongModel(SongModel):
                 name=item.owner.name,
             )],
             duration=item.duration.total_seconds() * 1000,
+            pic_url=item.pic,
         )
 
     @classmethod
@@ -122,6 +124,7 @@ class BSongModel(SongModel):
                 name=result.author,
             )],
             duration=result.duration.total_seconds() * 1000,
+            pic_url=result.pic,
         )
 
     @classmethod
@@ -147,8 +150,8 @@ class BSongModel(SongModel):
                 name=result.owner.name,
             )],
             duration=result.duration.total_seconds() * 1000,
-            lyric=lrc,
-            exists=ModelExistence.yes,
+            lyric=lrc or '',
+            pic_url=result.pic,
         )
 
     @classmethod
@@ -200,9 +203,7 @@ class BAlbumModel(AlbumModel):
         )
 
 
-class BSearchModel(SearchModel):
-    PROVIDER_ID = __identifier__
-
+class BSearchModel:
     # ['q', 'songs', 'playlists', 'artists', 'albums', 'videos']
     q: str
     songs = List[BSongModel]
@@ -266,19 +267,16 @@ class BSearchModel(SearchModel):
                 videos = list(map(cls.search_live_model, results))
             case SearchType.BANGUMI:
                 albums = list(map(cls.search_media_model, results))
-        return cls(
-            source=PROVIDER_ID,
+        return SimpleSearchResult(
             q=request[0].keyword if isinstance(request, Tuple) else request.keyword,
-            songs=songs,
-            artists=artists,
-            videos=videos,
-            albums=albums,
+            songs=songs or [],
+            artists=artists or [],
+            videos=videos or [],
+            albums=albums or [],
         )
 
 
 class BPlaylistModel(PlaylistModel):
-    PROVIDER_ID = __identifier__
-
     count: int
 
     @classmethod
@@ -446,8 +444,6 @@ class BPlaylistModel(PlaylistModel):
 
 
 class BArtistModel(ArtistModel):
-    PROVIDER_ID = __identifier__
-
     @classmethod
     def create_model(cls, resp: UserInfoResponse, video_resp: UserBestVideoResponse) -> 'BArtistModel':
         alias = []
@@ -466,8 +462,6 @@ class BArtistModel(ArtistModel):
 
 
 class BCommentModel(CommentModel):
-    PROVIDER_ID = __identifier__
-
     @classmethod
     def create_model(cls, reply: VideoHotCommentsResponse.VideoHotCommentsResponseData.Reply):
         return cls(
